%bcond_with bootstrap

Name:           velocity
Version:        2.3
Release:        %mkrel 2
Group:          Development/Java
Summary:        Java-based template engine
License:        ASL 2.0
URL:            https://velocity.apache.org/
BuildArch:      noarch
#ExclusiveArch:  %{java_arches} noarch

Source0:        https://github.com/apache/velocity-engine/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz

Patch0:         0001-Template-is-a-reserved-keyword-in-javacc.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.codehaus.mojo:extra-enforcer-rules)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(junit:junit)
%endif

%description
Velocity is a Java-based template engine. It permits anyone to use the
simple yet powerful template language to reference objects defined in
Java code.
When Velocity is used for web development, Web designers can work in
parallel with Java programmers to develop web sites according to the
Model-View-Controller (MVC) model, meaning that web page designers can
focus solely on creating a site that looks good, and programmers can
focus solely on writing top-notch code. Velocity separates Java code
from the web pages, making the web site more maintainable over the long
run and providing a viable alternative to Java Server Pages (JSPs) or
PHP.
Velocity's capabilities reach well beyond the realm of web sites; for
example, it can generate SQL and PostScript and XML (see Anakia for more
information on XML transformations) from templates. It can be used
either as a standalone utility for generating source code and reports,
or as an integrated component of other systems. Velocity also provides
template services for the Turbine web application framework.
Velocity+Turbine provides a template service that will allow web
applications to be developed according to a true MVC model.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
Javadoc for %{name}.

%prep
%setup -q -n velocity-engine-%{version}
%patch -P 0 -p1

%mvn_alias : velocity:velocity
%mvn_alias : org.apache.velocity:velocity

%pom_remove_parent
%pom_xpath_inject pom:project "<groupId>org.apache.velocity</groupId>"

%pom_disable_module spring-velocity-support
%pom_disable_module velocity-custom-parser-example
%pom_disable_module velocity-engine-examples
%pom_disable_module velocity-engine-scripting

%pom_remove_plugin :maven-javadoc-plugin

%pom_remove_plugin :templating-maven-plugin velocity-engine-core
sed 's/${project.version}/%{version}/' \
    velocity-engine-core/src/main/java-templates/org/apache/velocity/runtime/VelocityEngineVersion.java \
   >velocity-engine-core/src/main/java/org/apache/velocity/runtime/VelocityEngineVersion.java

%pom_remove_plugin com.google.code.maven-replacer-plugin:replacer velocity-engine-core
%pom_remove_plugin :maven-shade-plugin velocity-engine-core

%pom_xpath_remove "pom:dependency[pom:scope='test']" velocity-engine-core

%build
%mvn_build -f -- -Djavacc.visitor=false

%install
%mvn_install

%files -f .mfiles
%doc README.md
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE


%changelog
* Fri May 17 2024 ns80 <ns80> 2.3-2.mga10
+ Revision: 2064598
- build without bootstrap

* Fri May 17 2024 ns80 <ns80> 2.3-1.mga10
+ Revision: 2064570
- bootstrap build
- new version 2.3 for modello 2.1.2 and java 21

* Mon Jul 25 2022 neoclust <neoclust> 1.7-40.mga9
+ Revision: 1871136
- Disable bootstrap

* Sun Jul 24 2022 neoclust <neoclust> 1.7-39.mga9
+ Revision: 1870964
- Add bootstrap build mode
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Apr 02 2021 neoclust <neoclust> 0:1.7-33.mga9
+ Revision: 1712849
- Add P100: Fixes CVE-2020-13936 (mga#28681)

* Thu Jan 07 2021 neoclust <neoclust> 0:1.7-33.mga8
+ Revision: 1669541
- Fix Removal of log4j

* Tue Dec 29 2020 neoclust <neoclust> 0:1.7-25.mga8
+ Revision: 1664757
- Default to JDK logging and drop commons-logging and log4j12 implementations.

* Mon Sep 07 2020 daviddavid <daviddavid> 0:1.7-24.mga8
+ Revision: 1623052
- Port to commons-lang3
- Ignore test case that fails on Java 11
- Rebuilt for JDK-11

* Fri Feb 14 2020 umeabot <umeabot> 0:1.7-23.mga8
+ Revision: 1520751
- Mageia 8 Mass Rebuild

* Wed Dec 05 2018 daviddavid <daviddavid> 0:1.7-22.mga7
+ Revision: 1338535
- Repack the tarball without binaries
- Add hsqldb conditional
- Switch to glassfish-servlet-api

* Wed Sep 19 2018 umeabot <umeabot> 0:1.7-21.mga7
+ Revision: 1276950
- Mageia 7 Mass Rebuild

* Thu Mar 17 2016 neoclust <neoclust> 0:1.7-20.mga6
+ Revision: 992530
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0:1.7-19.mga6
+ Revision: 978215
- First rebuild of the java stack
- sync package velocity with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Dec 28 2014 pterjan <pterjan> 0:1.7-13.mga5
+ Revision: 806793
- Clean rebuild
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.7-11.mga5
+ Revision: 746267
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.7-10.mga5
+ Revision: 690195
- Mageia 5 Mass Rebuild

* Tue Dec 31 2013 dmorgan <dmorgan> 0:1.7-9.mga4
+ Revision: 563678
- Fix Build
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 dmorgan <dmorgan> 0:1.7-7.mga4
+ Revision: 451092
- Install NOTICE files

* Mon Jan 14 2013 umeabot <umeabot> 0:1.7-6.mga3
+ Revision: 385399
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Sep 11 2012 dmorgan <dmorgan> 0:1.7-5.mga3
+ Revision: 292356
- Rebuild against Java7

* Mon Jul 09 2012 dmorgan <dmorgan> 0:1.7-4.mga3
+ Revision: 268959
- New version 1.7

* Mon Jan 24 2011 dmorgan <dmorgan> 0:1.6.4-1.mga1
+ Revision: 38103
- Fix file list
- Fix source0
- Update with opensuse

* Sun Jan 16 2011 dmorgan <dmorgan> 0:1.5-2.0.2.mga1
+ Revision: 20296
- imported package velocity


* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 0:1.5-2.0.2mdv2009.0
+ Revision: 136570
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:1.5-2.0.2mdv2008.1
+ Revision: 121046
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sun Dec 09 2007 Alexander Kurtakov <akurtakov@mandriva.org> 0:1.5-2.0.1mdv2008.1
+ Revision: 116759
- fix BR werken.xpath is in main, werken-xpath is in contrib
- fix pom.xml (sync with jpp)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.5-1.0.2mdv2008.0
+ Revision: 87243
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Tue Sep 04 2007 David Walluck <walluck@mandriva.org> 0:1.5-1.0.1mdv2008.0
+ Revision: 78951
- 1.5


* Fri Mar 16 2007 Christiaan Welvaart <spturtle@mandriva.org> 0:1.4-4.3mdv2007.1
+ Revision: 144749
- rebuild for 2007.1
- Import velocity

* Sun Jul 23 2006 David Walluck <walluck@mandriva.org> 0:1.4-4.1mdv2007.0
- bump release

* Sun Jun 04 2006 David Walluck <walluck@mandriva.org> 0:1.4-3.2mdv2007.0
- rebuild for libgcj.so.7
- aot-compile

* Sun Sep 11 2005 David Walluck <walluck@mandriva.org> 0:1.4-3.1mdk
- release

* Thu Jun 16 2005 Gary Benson <gbenson@redhat.com> 0:1.4-3jpp_1fc
- Build into Fedora.

* Fri Jun 10 2005 Gary Benson <gbenson@redhat.com>
- Remove jarfiles from the tarball.

* Tue Jun 07 2005 Gary Benson <gbenson@redhat.com>
- Build with servletapi5.
- Add NOTICE file as per Apache License version 2.0.
- Skip some failing tests.

* Tue Oct 19 2004 Fernando Nasser <fnasser@redhat.com> 0:1.4-3jpp_1rh
- First Red Hat build

* Fri Sep 24 2004 Ralph Apel <r.apel at r-apel.de> 0:1.4-3jpp
- Adapt to jdom-1.0-1 replacing org.jdom.input.DefaultJDOMFactory
  by org.jdom.DefaultJDOMFactory in AnakiaJDOMFactory.java
  as well as using org.jdom.output.Format in AnakiaTask.java
- Therefore require jdom >= 0:1.0-1

* Fri Sep 03 2004 Ralph Apel <r.apel at r-apel.de> 0:1.4-2jpp
- Build with ant-1.6.2

* Tue Jun 08 2004 Kaj J. Niemi <kajtzu@fi.basen.net> 0:1.4-1jpp
- 1.4 final
- Patch #0 is unnecessary (upstream)
- We have to build velocity against servletapi3

